@@ -2,15 +2,10 @@ import gi
 
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
-
 from ks_includes.screen_panel import ScreenPanel
 
 
-def create_panel(*args):
-    return ExamplePanel(*args)
-
-
-class ExamplePanel(ScreenPanel):
+class Panel(ScreenPanel):
     def __init__(self, screen, title):
         super().__init__(screen, title)
 
