@@ -6,7 +6,7 @@ import gi
 gi.require_version("Gtk", "3.0")
 from gi.repository import GLib, Gtk, Pango
 from contextlib import suppress
-from math import pi, sqrt
+from math import pi, sqrt, trunc
 from statistics import median
 from time import time
 from ks_includes.screen_panel import ScreenPanel
@@ -683,7 +683,7 @@ class Panel(ScreenPanel):
 
     def update_progress(self, progress: float):
         self.progress = progress
-        self.labels['progress_text'].set_label(f"{progress * 100:.0f}%")
+        self.labels['progress_text'].set_label(f"{trunc(progress * 100)}%")
         self.labels['darea'].queue_draw()
 
     def set_state(self, state, msg=""):
@@ -765,7 +765,7 @@ class Panel(ScreenPanel):
             width = self._screen.width * 0.9
             height = self._screen.height / 4
         else:
-            width = self._screen.width / 3
+            width = self._screen.width * .25
             height = self._gtk.content_height * 0.47
         pixbuf = self.get_file_image(self.filename, width, height)
         logging.debug(self.filename)
@@ -780,11 +780,15 @@ class Panel(ScreenPanel):
         buttons = [
             {"name": _("Close"), "response": Gtk.ResponseType.CANCEL}
         ]
-        pixbuf = self.get_file_image(self.filename, self._screen.width * .9, self._screen.height * .5)
+        height = self._screen.height * .9 - self._gtk.font_size * 7.5
+        pixbuf = self.get_file_image(self.filename, self._screen.width * .9, height)
         if pixbuf is None:
             return
         image = Gtk.Image.new_from_pixbuf(pixbuf)
-        self._gtk.Dialog(self.filename, buttons, image, self.close_fullscreen_thumbnail)
+        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        box.add(image)
+        box.set_vexpand(True)
+        self._gtk.Dialog(self.filename, buttons, box, self.close_fullscreen_thumbnail)
 
     def close_fullscreen_thumbnail(self, dialog, response_id):
         self._gtk.remove_dialog(dialog)
